@@ -8,6 +8,7 @@ nonred.c
 q2d.c
 q2q.c
 qmatmult.c
+qo.c
 qoq.c
 qsign.c
 qsump.c
@@ -27,6 +28,7 @@ static R_CallMethodDef callMethods[]  = {
     {"d2q", (DL_FUNC) &d2q, 1},
     {"q2d", (DL_FUNC) &q2d, 1},
     {"q2q", (DL_FUNC) &q2q, 1},
+    {"qo", (DL_FUNC) &qo, 2},
     {"qoq", (DL_FUNC) &qoq, 3},
     {"qsign", (DL_FUNC) &qsign, 1},
     {"qsump", (DL_FUNC) &qsump, 2},
@@ -40,6 +42,8 @@ static R_CallMethodDef callMethods[]  = {
     {"redundant", (DL_FUNC) &redundant, 2},
     {"redundant_f", (DL_FUNC) &redundant_f, 2},
     {"nonred", (DL_FUNC) &nonred, 2},
+    {"impliedLinearity", (DL_FUNC) &impliedLinearity, 2},
+    {"impliedLinearity_f", (DL_FUNC) &impliedLinearity_f, 2},
     {NULL, NULL, 0}
 };
 
