@@ -133,6 +133,66 @@ SEXP lpcdd_f(SEXP hrep, SEXP objfun, SEXP minimize, SEXP solver)
     ddf_WriteLP(stderr, lp);
 #endif /* WOOF */
 
+    /* make map of rows of lp to rows of mf
+     * Fukuda duplicates each linearity row of mf, writing each equality
+     * as two inequalities.  Have to keep track of which are the two
+     * inequality rows so can combine the Lagrange multipliers for the
+     * two inequality rows (of lp) to make the Lagrange multiplier for the
+     * equality row (of mf).  Note that the R user only knows about mf,
+     * which has the dimensions of the input H-rep matrix.
+     *
+     * Problem: have to decide whether to use 0-origin or 1-origin indexing.
+     * When we are told what the Lagrange multipliers are, the indexing is
+     * 1-origin.  That's what Fukuda uses for rowsets.  On the other hand
+     * C uses 0-origin.  Let's us use that.  Thus we convert from 1-origin
+     * to 0-origin before lookup in the map we are about to create (not after).
+     *
+     * mapto is an integer vector of length lp->m.  It takes values in
+     * 0 ... mf->rowsize except that we are not sure that it is a function.
+     * Something may not add up.  Will allow value -1 to mean undefined
+     * (e. g., there is row of lp that does not correspond to any row of mf).
+     *
+     * Code to set up mapto should be copied as closely as possible from the
+     * code in 154--194 lines of the file cddlp.c (version 094f) in the
+     * function dd_Matrix2LP which creates lp.  Specifically (?) see the
+     * lines 173--188.  Note that dd_CreateLPData isn't given the data of
+     * mf so all copying of rows of mf to rows of lp occurs in dd_Matrix2LP.
+     *
+     * Meaning of mapto[j] is that row j (0-origin indexing) of lp->A
+     * corresponds to row mapto[j] (also 0-origin indexing) of mf->matrix
+     * where "corresponds" means that the rows are identical or one is the
+     * negative of the other.  To repeat mapto[j] == -1 means no row of
+     * original matrix corresponds.
+     */
+
+    int len_mapto = lp->m;
+    int *mapto = (int *) R_alloc(len_mapto, sizeof(int));
+    for (int j = 0; j < len_mapto; j++)
+        mapto[j] = -1;
+    {
+       int irev = mf->rowsize;                   /* cf line 174 cddlp_f.c */
+       for (int i = 1; i <= mf->rowsize; i++) {  /* cf line 175 cddlp_f.c */
+           if (set_member(i, mf->linset)) {      /* cf line 176 cddlp_f.c */
+               irev = irev + 1;                  /* cf line 177 cddlp_f.c */
+               mapto[irev - 1] = i - 1;          /* cf line 181 cddlp_f.c */
+           }                                     /* cf line 184 cddlp_f.c */
+           mapto[i - 1] = i - 1;                 /* cf line 186 cddlp_f.c */
+       }                                         /* cf line 189 cddlp_f.c */
+    }
+
+#ifdef WOOF
+    fprintf(stderr, "mf->rowsize = %d\n", mf->rowsize);
+    fprintf(stderr, "mf->colsize = %d\n", mf->colsize);
+
+    fprintf(stderr, "lp->eqnumber = %d\n", lp->eqnumber);
+    fprintf(stderr, "lp->m = %d\n", lp->m);
+    fprintf(stderr, "lp->d = %d\n", lp->d);
+    /* lp->equalityset;  */
+    /* lp->A */
+    fprintf(stderr, "correspondence of lp rows to mf rows (0-origin index)\n");
+    for (int j = 0; j < len_mapto; j++)
+        fprintf(stderr, "    lp row %d to mf row %d\n", j, mapto[j]);
+#endif /* WOOF */
 
     ddf_LPSolve(lp, sol, &err); 
 
@@ -209,10 +269,19 @@ SEXP lpcdd_f(SEXP hrep, SEXP objfun, SEXP minimize, SEXP solver)
         for (int j = 1; j < ncol - 1; j++) {
             int qux = lp->nbindex[j + 1];
             if (qux > 0) {
-                if (! (1 <= qux && qux <= nrow))
+                if (1 <= qux && qux <= len_mapto && mapto[qux - 1] != -1) {
+                    int the_row = mapto[qux - 1];
+                    int the_sign = mapto[qux - 1] == qux - 1;
+                    if (! (0 <= the_row && the_row < nrow))
+                        error("Can't happen.  Map mapto maps out of bounds");
+                    double ax = ddf_get_d(lp->dsol[j]);
+                    if (the_sign)
+                        REAL(bar)[the_row] += ax;
+                    else
+                        REAL(bar)[the_row] -= ax;
+                } else {
                     error("Can't happen.  Dual solution index out of bounds");
-                double ax = ddf_get_d(lp->dsol[j]);
-                REAL(bar)[qux - 1] = ax;
+                }
             }
         }
         {
@@ -243,10 +312,19 @@ SEXP lpcdd_f(SEXP hrep, SEXP objfun, SEXP minimize, SEXP solver)
         for (int j = 1; j < ncol - 1; j++) {
             int qux = lp->nbindex[j + 1];
             if (qux > 0) {
-                if (! (1 <= qux && qux <= nrow))
+                if (1 <= qux && qux <= len_mapto && mapto[qux - 1] != -1) {
+                    int the_row = mapto[qux - 1];
+                    int the_sign = mapto[qux - 1] == qux - 1;
+                    if (! (0 <= the_row && the_row < nrow))
+                        error("Can't happen.  Map mapto maps out of bounds");
+                    double ax = ddf_get_d(lp->dsol[j]);
+                    if (the_sign)
+                        REAL(foo)[the_row] += ax;
+                    else
+                        REAL(foo)[the_row] -= ax;
+                } else {
                     error("Can't happen.  Dual solution index out of bounds");
-                double ax = ddf_get_d(lp->dsol[j]);
-                REAL(foo)[qux - 1] = ax;
+                }
             }
         }
         {
